 
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Runtime.Serialization;

using Syncfusion.Drawing;
using Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;

namespace CustomControl
{

	// The model class is mainly derived to make
	// CreateRenderer return our derived renderer class.
	// Here we add an internal member, ddForm, to hold our Form
	// that we want to show in our popup. We set this member
	// in the constructor call. We also override OnQueryPrefferedClientSize
	// to allow for the button during optimal sizing calls.
	
	
	public class DropDownFormCellModel : GridStaticCellModel
	{
	
		protected DropDownFormCellModel(SerializationInfo info, StreamingContext context)
			: base(info, context)
		{
		}

		// sets ddForm and also reserves space for our button...
		public DropDownFormCellModel(GridModel grid)
			: base(grid)
		{				
			ButtonBarSize = new Size(14, 18);
		}
	
		//note that this method create our new derived renderer
		public override GridCellRendererBase CreateRenderer(GridControlBase control)
		{
			return new DropDownFormCellRenderer(control, this);
		}

		//used to provide optimal height and width for cell (as in grid.ColWidths.ResizeToFit calls)
		protected override Size OnQueryPrefferedClientSize(Graphics g, int rowIndex, int colIndex, GridStyleInfo style, GridQueryBounds queryBounds)
		{
			Size sz = base.OnQueryPrefferedClientSize(g, rowIndex, colIndex, style, queryBounds);

			//adjust to allow for button width
			sz.Width = sz.Width + ButtonBarSize.Width;

			return sz;
		}

	}


	// The renderer class handles the UI part of the cell
	// functionality. We use the constructor add the button,
	// cashe a reference to the cell model's form member.
	// The only method overridden is the OnButtonClicked which
	// is hit when the user clicks the button we added. In this 
	// method, we drop the form using ShowDialog. Upon return,
	// based on DialogResult, the changed values may be saved.

	public class DropDownFormCellRenderer: GridStaticCellRenderer
	{
		public DropDownFormCellRenderer(GridControlBase grid, GridCellModelBase cellModel)
			: base(grid, cellModel)
		{	
			this.AddButton(new GridCellComboBoxButton(this));
		}		
		
//		protected override void OnButtonClicked(int rowIndex, int colIndex, int button)
//		{	
//			MessageBox.Show("Custom Control");
//		}		
	}
}